@@ -1,14 +1,15 @@
 #!/usr/bin/env perl
 
+use v5.16;
 use strict;
 use warnings;
 
-use R;
+use Statistics::NiceR;
 
-my $r = R->new;
+my $r = Statistics::NiceR->new;
 my $face_data = $r->eval_parse(q{
 	library(aplpack)
 	faces(iris[1:20,1:4])
 	});
 
-<STDIN>;
+say "Press return to continue..."; <STDIN>;
